@@ -23,13 +23,12 @@ from pm4py.objects.conversion.log import converter as log_converter
 from pm4py.util.xes_constants import DEFAULT_NAME_KEY, DEFAULT_TRACEID_KEY
 from pm4py.objects.log.obj import Trace
 import time
+from pm4py.util.lp import solver
 from pm4py.util import exec_utils
 from enum import Enum
 import sys
 from pm4py.util.constants import PARAMETER_CONSTANT_ACTIVITY_KEY, PARAMETER_CONSTANT_CASEID_KEY
 import pkgutil
-from concurrent.futures import ProcessPoolExecutor
-import multiprocessing
 from typing import Optional, Dict, Any, Union, Tuple
 from pm4py.objects.log.obj import EventLog, EventStream, Trace
 from pm4py.objects.petri_net.obj import PetriNet, Marking
@@ -66,7 +65,11 @@ class Parameters(Enum):
     EXPONENT="theta"
 
 
-DEFAULT_VARIANT = Variants.VERSION_STATE_EQUATION_A_STAR
+
+DEFAULT_VARIANT = Variants.VERSION_DIJKSTRA_LESS_MEMORY
+if solver.DEFAULT_LP_SOLVER_VARIANT is not None:
+    DEFAULT_VARIANT = Variants.VERSION_STATE_EQUATION_A_STAR
+
 VERSION_STATE_EQUATION_A_STAR = Variants.VERSION_STATE_EQUATION_A_STAR
 VERSION_DIJKSTRA_NO_HEURISTICS = Variants.VERSION_DIJKSTRA_NO_HEURISTICS
 VERSION_DIJKSTRA_LESS_MEMORY = Variants.VERSION_DIJKSTRA_LESS_MEMORY
@@ -133,30 +136,32 @@ def apply_trace(trace, petri_net, initial_marking, final_marking, parameters=Non
     # Instead of using the length of the trace, use the sum of the trace cost function
     trace_cost_function_sum = sum(trace_cost_function)
 
-    ltrace_bwc = trace_cost_function_sum + best_worst_cost
+    if ali is not None and best_worst_cost is not None:
+        ltrace_bwc = trace_cost_function_sum + best_worst_cost
 
-    fitness = 1 - (ali['cost'] // align_utils.STD_MODEL_LOG_MOVE_COST) / (
-                ltrace_bwc // align_utils.STD_MODEL_LOG_MOVE_COST) if ltrace_bwc > 0 else 0
+        fitness_num = ali['cost'] // align_utils.STD_MODEL_LOG_MOVE_COST
+        fitness_den = ltrace_bwc // align_utils.STD_MODEL_LOG_MOVE_COST
+        fitness = 1 - fitness_num / fitness_den if fitness_den > 0 else 0
 
-    # other possibility: avoid integer division but proceed to rounding.
-    # could lead to small differences with respect to the adopted-since-now fitness
-    # (since it is rounded)
+        # other possibility: avoid integer division but proceed to rounding.
+        # could lead to small differences with respect to the adopted-since-now fitness
+        # (since it is rounded)
 
-    """
-    initial_trace_cost_function = exec_utils.get_param_value(Parameters.PARAM_TRACE_COST_FUNCTION, parameters, None)
-    initial_model_cost_function = exec_utils.get_param_value(Parameters.PARAM_MODEL_COST_FUNCTION, parameters, None)
-    initial_sync_cost_function = exec_utils.get_param_value(Parameters.PARAM_SYNC_COST_FUNCTION, parameters, None)
-    uses_standard_cost_function = initial_trace_cost_function is None and initial_model_cost_function is None and \
-                                initial_sync_cost_function is None
-        
-    fitness = 1 - ali['cost'] / ltrace_bwc if ltrace_bwc > 0 else 0
-    fitness_round_digits = exec_utils.get_param_value(Parameters.FITNESS_ROUND_DIGITS, parameters, 3)
-    fitness = round(fitness, fitness_round_digits)
-    """
+        """
+        initial_trace_cost_function = exec_utils.get_param_value(Parameters.PARAM_TRACE_COST_FUNCTION, parameters, None)
+        initial_model_cost_function = exec_utils.get_param_value(Parameters.PARAM_MODEL_COST_FUNCTION, parameters, None)
+        initial_sync_cost_function = exec_utils.get_param_value(Parameters.PARAM_SYNC_COST_FUNCTION, parameters, None)
+        uses_standard_cost_function = initial_trace_cost_function is None and initial_model_cost_function is None and \
+                                    initial_sync_cost_function is None
+            
+        fitness = 1 - ali['cost'] / ltrace_bwc if ltrace_bwc > 0 else 0
+        fitness_round_digits = exec_utils.get_param_value(Parameters.FITNESS_ROUND_DIGITS, parameters, 3)
+        fitness = round(fitness, fitness_round_digits)
+        """
 
-    ali["fitness"] = fitness
-    # returning also the best worst cost, for log fitness computation
-    ali["bwc"] = ltrace_bwc
+        ali["fitness"] = fitness
+        # returning also the best worst cost, for log fitness computation
+        ali["bwc"] = ltrace_bwc
 
     return ali
 
@@ -190,8 +195,9 @@ def apply_log(log, petri_net, initial_marking, final_marking, parameters=None, v
     if parameters is None:
         parameters = dict()
 
-    if not check_soundness.check_easy_soundness_net_in_fin_marking(petri_net, initial_marking, final_marking):
-        raise Exception("trying to apply alignments on a Petri net that is not a easy sound net!!")
+    if solver.DEFAULT_LP_SOLVER_VARIANT is not None:
+        if not check_soundness.check_easy_soundness_net_in_fin_marking(petri_net, initial_marking, final_marking):
+            raise Exception("trying to apply alignments on a Petri net that is not a easy sound net!!")
 
     start_time = time.time()
     max_align_time = exec_utils.get_param_value(Parameters.PARAM_MAX_ALIGN_TIME, parameters,
@@ -244,6 +250,8 @@ def apply_multiprocessing(log, petri_net, initial_marking, final_marking, parame
     if parameters is None:
         parameters = {}
 
+    import multiprocessing
+
     num_cores = exec_utils.get_param_value(Parameters.CORES, parameters, multiprocessing.cpu_count() - 2)
 
     best_worst_cost = __get_best_worst_cost(petri_net, initial_marking, final_marking, variant, parameters)
@@ -251,6 +259,8 @@ def apply_multiprocessing(log, petri_net, initial_marking, final_marking, parame
     parameters[Parameters.BEST_WORST_COST_INTERNAL] = best_worst_cost
 
     all_alignments = []
+
+    from concurrent.futures import ProcessPoolExecutor
     with ProcessPoolExecutor(max_workers=num_cores) as executor:
         futures = []
         for trace in one_tr_per_var:
