@@ -19,6 +19,9 @@ from pm4py.objects.log.obj import Trace
 from pm4py.objects.conversion.log import converter as log_conversion
 from enum import Enum
 from pm4py.util import exec_utils
+from typing import Optional, Dict, Any, Union, Tuple, List, Set
+from pm4py.objects.log.obj import EventLog, Trace
+import pandas as pd
 
 
 class Variants(Enum):
@@ -29,7 +32,7 @@ CLASSIC = Variants.CLASSIC
 DEFAULT_VARIANT = Variants.CLASSIC
 
 
-def apply(obj, model, variant=DEFAULT_VARIANT, parameters=None):
+def apply(obj: Union[EventLog, Trace, pd.DataFrame], model: Dict[str, Any], variant=DEFAULT_VARIANT, parameters: Optional[Dict[Any, Any]] = None) -> List[Set[Any]]:
     """
     Apply log-skeleton based conformance checking given an event log/trace
     and a log-skeleton model
@@ -59,14 +62,14 @@ def apply(obj, model, variant=DEFAULT_VARIANT, parameters=None):
         parameters = {}
 
     if type(obj) is Trace:
-        return exec_utils.get_variant(variant).apply_trace(log_conversion.apply(obj, parameters=parameters), model,
+        return exec_utils.get_variant(variant).apply_trace(log_conversion.apply(obj, variant=log_conversion.Variants.TO_EVENT_LOG, parameters=parameters), model,
                                                            parameters=parameters)
     else:
-        return exec_utils.get_variant(variant).apply_log(log_conversion.apply(obj, parameters=parameters), model,
+        return exec_utils.get_variant(variant).apply_log(log_conversion.apply(obj, variant=log_conversion.Variants.TO_EVENT_LOG, parameters=parameters), model,
                                                          parameters=parameters)
 
 
-def apply_from_variants_list(var_list, model, variant=DEFAULT_VARIANT, parameters=None):
+def apply_from_variants_list(var_list: List[List[str]], model: Dict[str, Any], variant=DEFAULT_VARIANT, parameters: Optional[Dict[Any, Any]] = None) -> List[Set[Any]]:
     """
     Performs conformance checking using the log skeleton,
     applying it from a list of variants
@@ -94,7 +97,7 @@ def apply_from_variants_list(var_list, model, variant=DEFAULT_VARIANT, parameter
     return exec_utils.get_variant(variant).apply_from_variants_list(var_list, model, parameters=parameters)
 
 
-def get_diagnostics_dataframe(log, conf_result, variant=DEFAULT_VARIANT, parameters=None):
+def get_diagnostics_dataframe(log: EventLog, conf_result: List[Set[Any]], variant=DEFAULT_VARIANT, parameters: Optional[Dict[Any, Any]] = None) -> pd.DataFrame:
     """
     Gets the diagnostics dataframe from a log and the results
     of log skeleton-based conformance checking
