@@ -18,9 +18,9 @@ import datetime
 from collections import Counter
 from enum import Enum
 
-from pm4py.objects.log import log as log_instance
-from pm4py.objects.petri import semantics
-from pm4py.objects.petri.petrinet import PetriNet
+from pm4py.objects.log import obj as log_instance
+from pm4py.objects.petri_net import semantics
+from pm4py.objects.petri_net.obj import PetriNet
 from pm4py.util import constants
 from pm4py.util import exec_utils
 from pm4py.util import xes_constants
